@@ -1,5 +1,5 @@
 package App::GitGot::Command::clone;
-$App::GitGot::Command::clone::VERSION = '1.28'; # TRIAL
+$App::GitGot::Command::clone::VERSION = '1.29'; # TRIAL
 # ABSTRACT: clone a remote repo and add it to your config
 use 5.014;
 
@@ -18,10 +18,12 @@ use namespace::autoclean;
 sub options {
   my( $class , $app ) = @_;
   return (
-    [ 'defaults|D' => 'FIXME' ] ,
+    [ 'defaults|D' => 'use the default choices for all prompts' ] ,
   );
 }
 
+sub _use_io_page { 0 }
+
 sub _execute {
   my ( $self, $opt, $args ) = @_;
 
@@ -54,6 +56,7 @@ sub _execute {
   }});
   $new_entry->{tags} = $tags if $tags;
 
+  say "Cloning into '$path'..." unless $self->quiet;
   $new_entry->clone( $repo , $path );
 
   $self->add_repo( $new_entry );
@@ -62,8 +65,6 @@ sub _execute {
 
 1;
 
-### FIXME docs
-
 __END__
 
 =pod
@@ -76,7 +77,17 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.28
+version 1.29
+
+=head1 SYNOPSIS
+
+    # clone repository and add to got config
+    $ got clone <git repo url>
+    # prompts for name, path, tags, etc.
+
+    # clone repository and add to got config
+    # using defaults for all prompts
+    $ got clone -D <git repo url>
 
 =head1 AUTHOR
 
